@@ -1,5 +1,5 @@
 import numpy as np
-import pdb
+
 def float_ndarray_to_dict(arr):
     return np_arr_to_dict(arr)
 
@@ -16,7 +16,6 @@ def string_to_float(string):
     return float(string)
 
 def np_arr_to_dict(arr):
-    # pdb.set_trace()
     return {'arr': arr.tolist(),
         'shape':list(arr.shape),
         'dtype':str(arr.dtype)
